#[non_exhaustive]pub enum Error {
InvalidBlockSize(usize),
BlockSizeMismatch {
expected: usize,
got: usize,
},
DuplicateIndex(usize),
IndexOutOfRange(usize),
}Expand description
Errors returned by [encode] and [recover].
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidBlockSize(usize)
Block size is zero or not a multiple of BLOCK_ALIGNMENT.
BlockSizeMismatch
Not all blocks have the same length. expected is the length of the first block.
DuplicateIndex(usize)
The same block index appeared more than once across the inputs.
IndexOutOfRange(usize)
A block index is out of range; valid indices are 0..N.